/*
 * NavigatorTest.java
 * 
 * Copyright 2009 by RidgeSoft, LLC., PO Box 482, Pleasanton, CA  94566, U.S.A.
 * www.ridgesoft.com
 *
 * RidgeSoft grants you the right to use, modify, make derivative works and
 * redistribute this source file provided you do not remove this copyright notice.
 */

import com.ridgesoft.intellibrain.IntelliBrain;
import com.ridgesoft.io.Display;
import com.ridgesoft.robotics.Motor;
import com.ridgesoft.robotics.ContinuousRotationServo;
import com.ridgesoft.robotics.ShaftEncoder;
import com.ridgesoft.robotics.AnalogShaftEncoder;
import com.ridgesoft.robotics.DirectionListener;
import com.ridgesoft.robotics.Localizer;
import com.ridgesoft.robotics.OdometricLocalizer;

public class NavigatorTest {
    public static void main(String[] args) {
        Display display = IntelliBrain.getLcdDisplay();
        display.print(0, "Navigator Test");
        display.print(1, "");

        ShaftEncoder leftEncoder = new AnalogShaftEncoder(
                IntelliBrain.getAnalogInput(4), 250, 750, 30, Thread.MAX_PRIORITY);
        ShaftEncoder rightEncoder = new AnalogShaftEncoder(
                IntelliBrain.getAnalogInput(5), 250, 750, 30, Thread.MAX_PRIORITY);

        Localizer localizer = new OdometricLocalizer(leftEncoder, rightEncoder,
                2.65f, 4.55f, 16, Thread.MAX_PRIORITY - 1, 30);

        Motor leftMotor = new ContinuousRotationServo(IntelliBrain.getServo(1),
                false, 14, (DirectionListener) leftEncoder);
        Motor rightMotor = new ContinuousRotationServo(
                IntelliBrain.getServo(2), true, 14,
                (DirectionListener) rightEncoder);

        Navigator navigator = new DifferentialDriveNavigator(leftMotor,
                rightMotor, localizer, 8, 6, 25.0f, 0.5f, 0.08f,
                Thread.MAX_PRIORITY - 2, 50);

        // navigateHeading(navigator, 45.0f, 10);
        // driveForward(navigator, 100.0f);
        // rotate(navigator, 180.0f);
        // navigateSquare(navigator, 16.0f);
        navigateFigureEight(navigator, 48.0f, 32.0f);
    }

    public static void navigateHeading(Navigator navigator, float degrees,
            int seconds) {
        navigator.go((float) Math.toRadians(degrees));
        try {
            Thread.sleep(seconds * 1000);
        }
        catch (Exception e) {
        }
        navigator.stop();
    }

    public static void driveForward(Navigator navigator, float distance) {
        navigator.moveTo(distance, 0.0f, true);
    }

    public static void rotate(Navigator navigator, float degrees) {
        navigator.turnTo((float) Math.toRadians(degrees), true);
    }

    public static void navigateSquare(Navigator navigator, float size) {
        navigator.moveTo(size, 0.0f, true);
        navigator.moveTo(size, -size, true);
        navigator.moveTo(0.0f, -size, true);
        navigator.moveTo(0.0f, 0.0f, true);
        navigator.turnTo(0.0f, true);
    }

    public static void navigateFigureEight(Navigator navigator, float height,
            float width) {
        navigator.moveTo(height, width, true);
        navigator.moveTo(height, 0.0f, true);
        navigator.moveTo(0.0f, width, true);
        navigator.moveTo(0.0f, 0.0f, true);
        navigator.turnTo(0.0f, true);
    }
}