/*
 * TurnBehavior.java
 * 
 * Copyright 2009 by RidgeSoft, LLC., PO Box 482, Pleasanton, CA 94566, U.S.A.
 * www.ridgesoft.com
 * 
 * RidgeSoft grants you the right to use, modify, make derivative works and
 * redistribute this source file provided you do not remove this copyright
 * notice.
 */

import com.ridgesoft.robotics.Localizer;
import com.ridgesoft.robotics.Navigator;
import com.ridgesoft.robotics.NavigatorListener;
import java.util.Random;

public class TurnBehavior implements Behavior, NavigatorListener {
    private boolean isActive;
    private Localizer localizer;
    private Navigator navigator;
    private int period;
    private long nextTime;
    private boolean turning;
    private Random random;

    public TurnBehavior(Localizer localizer, Navigator navigator, int periodSeconds,
            long seed) {
        this.localizer = localizer;
        this.navigator = navigator;
        period = periodSeconds * 1000;
        nextTime = System.currentTimeMillis() + period;
        isActive = false;
        turning = false;
        random = new Random(seed);
    }

    public boolean poll() {
        if (turning)
            return true;

        if (System.currentTimeMillis() > nextTime) {
            if (isActive) {
                turning = true;
                nextTime = System.currentTimeMillis() + period;
                float newHeading = localizer.getPose().heading
                        + (float) Math.toRadians(random.nextInt(270) + 45.0f);
                navigator.turnTo(newHeading, this);
            }
            return true;
        }

        return false;
    }

    public void navigationOperationTerminated(boolean completed) {
        turning = false;
    }

    public void setActive(boolean isActive) {
        this.isActive = isActive;
    }
}