/*
 * VacuumCleaner.java
 * 
 * Copyright 2009 by RidgeSoft, LLC., PO Box 482, Pleasanton, CA 94566, U.S.A.
 * www.ridgesoft.com
 * 
 * RidgeSoft grants you the right to use, modify, make derivative works and
 * redistribute this source file provided you do not remove this copyright
 * notice.
 */

import com.ridgesoft.intellibrain.IntelliBrain;
import com.ridgesoft.io.Display;
import com.ridgesoft.robotics.Motor;
import com.ridgesoft.robotics.AnalogInput;
import com.ridgesoft.robotics.ContinuousRotationServo;
import com.ridgesoft.robotics.ShaftEncoder;
import com.ridgesoft.robotics.AnalogShaftEncoder;
import com.ridgesoft.robotics.DirectionListener;
import com.ridgesoft.robotics.Localizer;
import com.ridgesoft.robotics.OdometricLocalizer;
import com.ridgesoft.robotics.Navigator;
import com.ridgesoft.robotics.DifferentialDriveNavigator;

public class VacuumCleaner {
    public static void main(String args[]) {
        Display display = IntelliBrain.getLcdDisplay();
        display.print(0, "Vacuum Cleaner");
        display.print(1, "");

        AnalogInput leftRange = IntelliBrain.getAnalogInput(1);
        AnalogInput rightRange = IntelliBrain.getAnalogInput(2);

        ShaftEncoder leftEncoder = new AnalogShaftEncoder(IntelliBrain
                .getAnalogInput(4), 250, 750, 30, Thread.MAX_PRIORITY);
        ShaftEncoder rightEncoder = new AnalogShaftEncoder(IntelliBrain
                .getAnalogInput(5), 250, 750, 30, Thread.MAX_PRIORITY);

        Localizer localizer = new OdometricLocalizer(leftEncoder, rightEncoder,
                2.65f, 4.55f, 16, Thread.MAX_PRIORITY - 1, 30);

        Motor leftMotor = new ContinuousRotationServo(IntelliBrain.getServo(1),
                false, 14, (DirectionListener) leftEncoder);
        Motor rightMotor = new ContinuousRotationServo(
                IntelliBrain.getServo(2), true, 14,
                (DirectionListener) rightEncoder);

        Navigator navigator = new DifferentialDriveNavigator(leftMotor,
                rightMotor, localizer, 8, 6, 25.0f, 0.5f, 0.08f,
                Thread.MAX_PRIORITY - 2, 50);

        Behavior behaviors[] = new Behavior[] {
                new AvoidBehavior(localizer, navigator, leftRange, rightRange,
                        200, 0.7f, 3000),
                new ReturnHomeBehavior(navigator, 30),
                new TurnBehavior(localizer, navigator, 10,
                        (leftRange.sample() * rightRange.sample())),
                new DriveBehavior(localizer, navigator), };

        BehaviorArbiter arbiter = new BehaviorArbiter(behaviors, 200);
        arbiter.setPriority(Thread.MAX_PRIORITY - 3);
        arbiter.start();
    }
}