/*
 * Wanderer.java
 * 
 * Copyright 2009 by RidgeSoft, LLC., PO Box 482, Pleasanton, CA 94566, U.S.A.
 * www.ridgesoft.com
 * 
 * RidgeSoft grants you the right to use, modify, make derivative works and
 * redistribute this source file provided you do not remove this copyright
 * notice.
 */

import com.ridgesoft.intellibrain.IntelliBrain;
import com.ridgesoft.io.Display;
import com.ridgesoft.robotics.AnalogInput;
import com.ridgesoft.robotics.ContinuousRotationServo;
import com.ridgesoft.robotics.Motor;

/**
 * This class is an example program that demonstrates programming the
 * IntelliBrain-Bot educational robot to use infra-red range sensors to sense
 * and avoid obstacles in its path as it wanders.
 * 
 * The robot drives straight ahead unless it detects an object in its path, in
 * which case it will turn away to avoid the object.
 */
public class Wanderer {
    private static final int MOTOR_POWER = 13;
    private static final int THRESHOLD = 300;

    private static Motor leftMotor;
    private static Motor rightMotor;

    public static void main(String[] args) {
        Display display = IntelliBrain.getLcdDisplay();
        display.print(0, "Wanderer");

        // Create motor objects for servo motors
        leftMotor = new ContinuousRotationServo(IntelliBrain.getServo(1),
                false, 14);
        rightMotor = new ContinuousRotationServo(IntelliBrain.getServo(2),
                true, 14);

        // Get input objects for the infrared range sensors
        AnalogInput leftRangeSensor = IntelliBrain.getAnalogInput(1);
        AnalogInput rightRangeSensor = IntelliBrain.getAnalogInput(2);

        // Loop forever, wandering and avoiding obstacles
        while (true) {
            // Display the range sensor readings
            display.print(1, "L: " + leftRangeSensor + " R: "
                    + rightRangeSensor);

            // Rotate if either sensor detects an obstacle, otherwise go forward
            if (leftRangeSensor.sample() > THRESHOLD)
                rotateRight();
            else if (rightRangeSensor.sample() > THRESHOLD)
                rotateLeft();
            else
                goForward();
        }
    }

    public static void goForward() {
        leftMotor.setPower(MOTOR_POWER);
        rightMotor.setPower(MOTOR_POWER);
    }

    public static void rotateRight() {
        leftMotor.setPower(MOTOR_POWER);
        rightMotor.setPower(-MOTOR_POWER);
    }

    public static void rotateLeft() {
        leftMotor.setPower(-MOTOR_POWER);
        rightMotor.setPower(MOTOR_POWER);
    }
}